OOKNET                             [ /  search the index  ]  
──────────────────────────────────────────────────────────────────────────────────────
══════════════════════════════════════════════════════════════════════════════════════
OOKNET   [ /  search  ]  
────────────────────────────────────────────────
════════════════════════════════════════════════
 
HASH      b733ba5a5f69
DATE      2025-09-05
SUBJECT   nix: update to 1026 period
FILES     1 CHANGED
HASH      b733ba5a5f69
DATE      2025-09-05
SUBJECT   nix: update to 1026 period
FILES     1 CHANGED
 

diff --git a/nix/apps/challenge-mode-leaderboard.nix b/nix/apps/challenge-mode-lea
derboard.nix
index 528214d..f494fa5 100644
--- a/nix/apps/challenge-mode-leaderboard.nix
+++ b/nix/apps/challenge-mode-leaderboard.nix
@@ -32,8 +32,8 @@
 
       def get_hardcoded_period_and_dungeons():
           # hardcoded values since the index endpoint is broken
-          # all records are now in period 1025
-          period_id = "1025"
+          # all records are now in period 1026
+          period_id = "1026"
 
           dungeons = [
               {"id": 2, "name": "Temple of the Jade Serpent", "slug": "temple-of-
the-jade-serpent"},

diff --git a/nix/apps/challenge-mode-leaderb
oard.nix b/nix/apps/challenge-mode-leaderboa
rd.nix
index 528214d..f494fa5 100644
--- a/nix/apps/challenge-mode-leaderboard.ni
x
+++ b/nix/apps/challenge-mode-leaderboard.ni
x
@@ -32,8 +32,8 @@
 
       def get_hardcoded_period_and_dungeons
():
           # hardcoded values since the inde
x endpoint is broken
-          # all records are now in period 1
025
-          period_id = "1025"
+          # all records are now in period 1
026
+          period_id = "1026"
 
           dungeons = [
               {"id": 2, "name": "Temple of 
the Jade Serpent", "slug": "temple-of-the-ja
de-serpent"},
 
[ BACK TO LOG ]
──────────────────────────────────────────────────────────────────────────────────────
OOKNET
────────────────────────────────────────────────
OOKNET